[![PyPI - Version](https://img.shields.io/pypi/v/elsheeto)](http://pypi.org/project/elsheeto/)
[![PyPI - Types](https://img.shields.io/pypi/types/elsheeto)](http://pypi.org/project/elsheeto/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/elsheeto)](http://pypi.org/project/elsheeto/)
[![CI](https://github.com/medgen-mainz/elsheeto/actions/workflows/main.yml/badge.svg)](https://github.com/medgen-mainz/elsheeto/actions/workflows/main.yml)
[![docs](https://app.readthedocs.org/projects/elsheeto/badge/?version=latest)](https://elsheeto.readthedocs.io/en/latest/)

# El Sheeto

I/O and models in type-annotated Python for NGS sample sheets: Illumina (v1) and Aviti

- Python: 3.13+
- License: MIT
- [Documentation at ReadTheDocs](https://elsheeto.readthedocs.io/en/latest/)
